@@ -105,13 +105,13 @@ class Main():
             token = input("缺少你的sm.ms访问令牌，请输入：")
             sysConfig.writeSmmsToken(token)
             print("访问令牌已保存，请重新运行程序")
-            exit()
         elif userExp.getErrorCode() == UserException.CODE_UPLOAD_ERROR:
             print("上传图片到sm.ms失败，请检查日志文件", sysConfig.getErrorLogFilePath())
-            exit()
+        elif userExp.getErrorCode() == UserException.CODE_TIMEOUT:
+            print(userExp.getErrorMsg())
         else:
             print("未定义错误，请联系开发者")
-            exit()
+        exit()
 
     def main(self):
         # 检索当前目录中的markdown文件
@@ -131,7 +131,9 @@ class Main():
         print("所有markdown文档已处理完毕")
 
     def outputHelpInfo(self):
-        with open(file='help.info', mode='r', encoding='UTF-8') as helpFileOpen:
+        sysConfig = Config()
+        dirPath = sysConfig.getCurrentDirPath()
+        with open(file=dirPath+'\\help.info', mode='r', encoding='UTF-8') as helpFileOpen:
             content = helpFileOpen.read()
             print(content)
 
@@ -143,8 +145,11 @@ class Main():
                 copyFilePath = self.getCopyFilePath(dir)
                 if os.path.exists(copyFilePath):
                     # 如果存在图床备份，进行还原操作
-                    if self.recoveryImgsInMarkdown(copyFilePath, dir):
-                        print("已成功还原markdown文件", dir, "的本地图库")
+                    try:
+                        if self.recoveryImgsInMarkdown(copyFilePath, dir):
+                            print("已成功还原markdown文件", dir, "的本地图库")
+                    except UserException as e:
+                        self.dealUserException(e)
         print("所有markdown文档已处理完毕")
 
     def copyImgFromWeb(self, webImg, localImgPath):
@@ -152,7 +157,7 @@ class Main():
             return
         if not os.path.exists(localImgPath):
             downloader = DownloadHelp()
-            downloader.download(webImg, localImgPath)
+            downloader.chunkDownload(webImg, localImgPath, timeout=2)
 
     def recoveryImgsInMarkdown(self, copyFilePath: 'copied markdown file path', orignalFile: 'orignal markdown file'):
         '''使用图床图片还原本地图库'''
